@@ -60,7 +60,9 @@ class CsvUtilities:
     @staticmethod
     def load_data(filepath,already_labeled = {}, skip_already_labeled=False):
         # csv format: [ID, TEXT, LABEL, SAMPLING_STRATEGY, CONFIDENCE]
-        
+        if  not filepath:
+            raise Exception("filepath param mus be provided")
+
         with open(filepath, 'r') as csvfile:
             data = []
             reader = csv.reader(csvfile)
@@ -344,18 +346,18 @@ class BlobStorageAPIUtilities:
         temp = os.path.join(os.getcwd(), "blob_api_temp_555")
         FolderUtilities.make_dir(temp)
         data_downloaded_file = os.path.join(temp, blob_name)
-        print("BlobStorageAPIUtilities.data_downloaded_file :",data_downloaded_file)
+        
         remote_file = "{0}/{1}/{2}".format(self.base_url, blob_container, blob_name)
-        print("BlobStorageAPIUtilities.remote_file :", remote_file)
+        
         is_data_file_downloaded =  FileUtilities.direct_download_file(remote_file,data_downloaded_file)
-        print("BlobStorageAPIUtilities.is_data_file_downloaded :", is_data_file_downloaded)
+        
         if is_data_file_downloaded == False:
             return False
-        print("BlobStorageAPIUtilities. ça passe")
+        
         xx = self._is_blob_not_found(data_downloaded_file)
-        print("BlobStorageAPIUtilities.xx :", xx)
+        
         result = not self._is_blob_not_found(data_downloaded_file)
-        print("BlobStorageAPIUtilities.result :", result)
+        
         shutil.rmtree(temp, ignore_errors=True)
 
         return result
@@ -521,7 +523,6 @@ class PipelinePublisher:
         #return published_pipeline.id, published_pipeline.endpoint
         return published_pipeline
 
-
 class EndpointPipelinePublisher:
     def __init__(self, ws):
         self.ws = ws
@@ -619,7 +620,6 @@ class WebServiceDeployer:
         #print(response.status_code)
         #print(response.elapsed)
         #print(response.json())
-
 class AllConstants:
     BLOB_STORAGE_CONNECTION_STRING = "DefaultEndpointsProtocol=https;AccountName=humlstorage;AccountKey=InGUfK++98C0tANJqmP3AbV5tTMpDj+5XikesQpjYWSH1MYxAspw5sbmfMcmMPgBGpYHVGuGtuEuGAICu3zFlw==;EndpointSuffix=core.windows.net"
     EXPERIMENT_NAME = "huml_experiment"
@@ -862,7 +862,7 @@ class FeaturesHandler:
         """
         feature_index = {}
 
-        if unlabeled_data is None :
+        if (unlabeled_data is None) | (unlabeled_data is "") :
             raise Exception("unlabeled data cannot be empty") 
 
         total_training_words = {}
